=== modified file 'bindings/Makefile.am'
--- bindings/Makefile.am	2011-01-25 15:52:54 +0000
+++ bindings/Makefile.am	2011-02-03 15:22:06 +0000
@@ -1,7 +1,10 @@
 if USE_GTK3
-SUBDIRS = mono
+SUBDIRS =	\
+	mono	\
+	vala
 else
 SUBDIRS =		\
 	mono		\
-	python
+	python		\
+	vala
 endif

=== added directory 'bindings/vala'
=== added file 'bindings/vala/Makefile.am'
--- bindings/vala/Makefile.am	1970-01-01 00:00:00 +0000
+++ bindings/vala/Makefile.am	2011-02-03 15:22:06 +0000
@@ -0,0 +1,32 @@
+SUBDIRS = . examples
+
+
+#########################
+# VAPI Files
+#########################
+
+if HAVE_INTROSPECTION
+
+if USE_GTK3
+GTKVAPI = gtk+-3.0
+else
+GTKVAPI = gtk+-2.0
+endif
+
+vapidir = $(datadir)/vala/vapi
+vapiprefix = appindicator$(VER)-0.1
+vapi_DATA = $(vapiprefix).vapi $(vapiprefix).deps
+DEPS = $(GTKVAPI)
+
+$(vapiprefix).deps:
+	echo $(DEPS) > $@
+
+$(vapiprefix).vapi: $(top_builddir)/src/AppIndicator$(VER)-0.1.gir $(vapiprefix).deps
+	$(VALA_API_GEN) --library=$(vapiprefix) \
+		--pkg $(GTKVAPI) \
+		$<
+	
+
+CLEANFILES = $(vapi_DATA)
+
+endif

=== added directory 'bindings/vala/examples'
=== added file 'bindings/vala/examples/Makefile.am'
--- bindings/vala/examples/Makefile.am	1970-01-01 00:00:00 +0000
+++ bindings/vala/examples/Makefile.am	2011-02-03 15:22:06 +0000
@@ -0,0 +1,14 @@
+
+TESTS = indicator-example
+VALAFILES = indicator-example.vala
+CLEANFILES = $(TESTS) *.c
+EXTRA_DIST = $(VALAFILES)
+
+VALAFLAGS = --pkg appindicator-0.1 --vapidir=$(top_builddir)/bindings/vala --save-temps
+
+if HAVE_VALAC
+$(TESTS): $(VALAFILES) Makefile.am
+	$(VALAC) $(VALAFLAGS) $(srcdir)/$(VALAFILES)
+
+all: $(TESTS)
+endif

=== added file 'bindings/vala/examples/indicator-example.vala'
--- bindings/vala/examples/indicator-example.vala	1970-01-01 00:00:00 +0000
+++ bindings/vala/examples/indicator-example.vala	2011-02-03 15:22:06 +0000
@@ -0,0 +1,45 @@
+using Gtk;
+using AppIndicator;
+
+public class IndicatorExample {
+    public static int main(string[] args) {
+		Gtk.init(ref args);
+	
+        var win = new Window();
+        win.title = "Indicator Test";
+        win.resize(200, 200);
+        win.destroy.connect(Gtk.main_quit);
+
+        var label = new Label("Hello, world!");
+        win.add(label);
+
+        var indicator = new Indicator(win.title, "indicator-messages",
+                                      IndicatorCategory.APPLICATION_STATUS);
+
+		indicator.set_status(IndicatorStatus.ACTIVE);
+        indicator.set_attention_icon("indicator-messages-new");
+
+        var menu = new Menu();
+        var item = new MenuItem.with_label("Foo");
+        item.activate.connect(() => {
+        	indicator.set_status(IndicatorStatus.ATTENTION);
+        });
+        item.show();
+        menu.append(item);
+
+
+        item = new MenuItem.with_label("Bar");
+        item.show();
+        item.activate.connect(() => {
+        	indicator.set_status(IndicatorStatus.ATTENTION);
+        });
+        menu.append(item);
+
+        indicator.set_menu(menu);
+
+        win.show_all();
+
+		Gtk.main();
+		return 0;
+    }
+}

=== modified file 'configure.ac'
--- configure.ac	2011-01-27 20:43:30 +0000
+++ configure.ac	2011-02-03 15:22:06 +0000
@@ -96,6 +96,13 @@
 AC_PATH_PROG([VALA_API_GEN], [vapigen])
 
 ###########################
+# Vala Compiler support
+###########################
+
+AM_PROG_VALAC([0.11.0])
+AM_CONDITIONAL(HAVE_VALAC, [test "x$VALAC" != "x"])
+
+###########################
 # Check for Mono support
 ###########################
 
@@ -205,6 +212,8 @@
 bindings/mono/examples/Makefile
 bindings/mono/examples/indicator-example
 bindings/python/Makefile
+bindings/vala/Makefile
+bindings/vala/examples/Makefile
 tests/Makefile
 example/Makefile
 docs/Makefile

=== modified file 'src/AppIndicator-0.1.metadata'
--- src/AppIndicator-0.1.metadata	2010-12-03 22:15:12 +0000
+++ src/AppIndicator-0.1.metadata	2011-02-03 15:22:06 +0000
@@ -1,1 +1,3 @@
 AppIndicator name="AppIndicator"
+Indicator.priv hidden="1"
+IndicatorPrivate hidden="1"

=== modified file 'src/Makefile.am'
--- src/Makefile.am	2011-01-25 15:53:55 +0000
+++ src/Makefile.am	2011-02-03 15:22:06 +0000
@@ -2,12 +2,10 @@
 VER=3
 lib_LTLIBRARIES = libappindicator3.la
 GTKGIR = Gtk-3.0
-GTKVAPI = gtk+-3.0
 else
 VER=
 lib_LTLIBRARIES = libappindicator.la
 GTKGIR = Gtk-2.0
-GTKVAPI = gtk+-2.0
 endif
 
 CLEANFILES =
@@ -45,7 +43,8 @@
 
 DISTCLEANFILES += app-indicator-enum-types.c
 
-libappindicatorincludedir=$(includedir)/libappindicator-0.1/libappindicator
+libappindicatorincludefolder=libappindicator
+libappindicatorincludedir=$(includedir)/libappindicator-0.1/$(libappindicatorincludefolder)
 
 libappindicator_headers = \
 	app-indicator.h
@@ -133,13 +132,13 @@
 if INTROSPECTION_TEN
 INTROSPECTION_SCANNER_ARGS = \
 	--add-include-path=$(srcdir) \
-	$(addprefix --c-include=src/, $(introspection_sources)) \
+	$(addprefix --c-include=$(libappindicatorincludefolder)/, $(libappindicator_headers)) \
 	--symbol-prefix=app \
 	--identifier-prefix=App
 else
 INTROSPECTION_SCANNER_ARGS = \
 	--add-include-path=$(srcdir) \
-	$(addprefix --c-include=src/, $(introspection_sources))
+	$(addprefix --c-include=$(libappindicatorincludefolder)/, $(libappindicator_headers))
 endif
 
 INTROSPECTION_COMPILER_ARGS = --includedir=$(builddir)
@@ -174,23 +173,3 @@
 CLEANFILES += $(gir_DATA) $(typelib_DATA)
 
 endif
-
-#########################
-# VAPI Files
-#########################
-
-if HAVE_INTROSPECTION
-
-vapidir = $(datadir)/vala/vapi
-vapi_DATA = AppIndicator$(VER)-0.1.vapi
-
-AppIndicator$(VER)-0.1.vapi: AppIndicator$(VER)-0.1.gir Makefile.am
-	$(VALA_API_GEN) --library=AppIndicator$(VER)-0.1 \
-		--pkg $(GTKVAPI) \
-		--vapidir=$(top_builddir)/src \
-		$<
-
-CLEANFILES += $(vapi_DATA)
-
-endif
-

